import matplotlib.pyplot as plt
import numpy as np 

style_path = '../paper.mplstyle'
plt.style.use(style_path)
plt.figure(figsize=(7, 3.5))

# Load the data from the file using numpy
data_D1 = np.loadtxt('data/TK_vs_a_DMu-0.6_D-1_U-6.dat')
data_D5 = np.loadtxt('data/TK_vs_a_DMu-0.6_D-5_U-6.dat')
data_D20 = np.loadtxt('data/TK_vs_a_DMu-0.6_D-20_U-6.dat')
data_D50 = np.loadtxt('data/TK_vs_a_DMu-0.6_D-50_U-6.dat')

a=0.5
b=1
# Perform the transformation
x_D1 = ((1 + data_D1[:, 0]) / (1 - data_D1[:, 0]) - 1)
y_D1 = data_D1[:, 1] * ((1 + data_D1[:, 0]) / (1 - data_D1[:, 0]))**a

x_D5 = ((1 + data_D5[:, 0]) / (1 - data_D5[:, 0]) - 1)
y_D5 = data_D5[:, 1] * ((1 + data_D5[:, 0]) / (1 - data_D5[:, 0]))**a

x_D20 = ((1 + data_D20[:, 0]) / (1 - data_D20[:, 0]) - 1)
y_D20 = data_D20[:, 1] * ((1 + data_D20[:, 0]) / (1 - data_D20[:, 0]))**a

x_D50 = ((1 + data_D50[:, 0]) / (1 - data_D50[:, 0]) - 1)
y_D50 = data_D50[:, 1] * ((1 + data_D50[:, 0]) / (1 - data_D50[:, 0]))**a

# Create a plot with a logarithmic y-axis
plt.plot(x_D1, y_D1, marker='o', linestyle='-', label=r'$D/\Gamma=1$', color='orange', lw=2, ms=7)
plt.plot(x_D1, y_D5, marker='D', linestyle='-', label=r'$D/\Gamma=5$', color='blue', lw=2, ms=7)
plt.plot(x_D1, y_D20, marker='s', linestyle='-', label=r'$D/\Gamma=20$', color='green', lw=2, ms=7)
plt.plot(x_D1, y_D50, marker='^', linestyle='-', label=r'$D/\Gamma=50$', color='red', lw=2, ms=7)

plt.yscale('log')  # Set y-axis scale to logarithmic

# Plot the function f(x) = exp(-pi/8 * 6 * x)
x_function = np.linspace(0, 5, 100)  # Generate x values
y_function = np.exp(-np.pi /(b* 8) * 6 * x_function)  # Calculate f(x)
plt.plot(x_function, y_function, linestyle='--', color='k', lw=3)

# Set labels and title
plt.xlabel(r'$\gamma-1$')
plt.ylabel(r'$T_0(\gamma)/T_0(0)\cdot \sqrt{\gamma}$')

# Show a legend
plt.legend()

plt.tight_layout() 
# Show the plot
#plt.show()
plt.savefig('fig1.png')
