import matplotlib.pyplot as plt
import numpy as np 
from matplotlib.ticker import ScalarFormatter

style_path = '../paper.mplstyle'
plt.style.use(style_path)

TK=0.001141659623270467
# Load the data from the file using numpy
data_gf_a1 = np.loadtxt('data/Gf_a-1.0')
data_gf_a0 = np.loadtxt('data/Gf_a-0.0')
data_gf_a05 = np.loadtxt('data/Gf_a-0.5')


data_gc1_a1 = np.loadtxt('data/Gc1_a-1.0')
data_gc1_a0 = np.loadtxt('data/Gc1_a-0.0')
data_gc1_a05 = np.loadtxt('data/Gc1_a-0.5')

data_gc2_a1 = np.loadtxt('data/Gc2_a-1.0')
data_gc2_a0 = np.loadtxt('data/Gc2_a-0.0')
data_gc2_a05 = np.loadtxt('data/Gc2_a-0.5')


# Create a figure and three subplots stacked vertically with shared x-axis and no spacing
fig, axs = plt.subplots(3, 1, figsize=(6, 4.5), sharex=True, gridspec_kw={'hspace': 0})


# Plot data on the subplots
axs[0].plot(data_gf_a1[:,0], -1/np.pi*data_gf_a1[:,2] , label=r'$\alpha=1.0$', color='r')
axs[0].plot(data_gf_a05[:,0], -1/np.pi*data_gf_a05[:,2] , label=r'$\alpha=0.5$', color='orange')
axs[0].plot(data_gf_a0[:,0], -1/np.pi*data_gf_a0[:,2] , label=r'$\alpha=0.0$', color='k')
#axs[0].legend()
axs[0].set_ylabel(r'$\rho^f(\omega)$')
axs[0].set_ylim(0, 0.15)  # Set the y-range for the first subplot
axs[0].set_xlim(-8, 8)  # Set the y-range for the first subplot

# Create a white box subplot
shift_x =0.0
shift_y =0.0
left, bottom, width, height = [0.625+shift_x, 0.61+shift_y, 0.34, 0.29]  # Adjust these values as needed
ax2 = fig.add_axes([left, bottom, width, height])
ax2.xaxis.set_visible(False)
ax2.yaxis.set_visible(False)
#ax2.set_facecolor('white')
ax2.set_facecolor((1.0, 1.0, 1.0, 1.0))
ax2.spines['top'].set_visible(False)
ax2.spines['right'].set_visible(False)
ax2.spines['bottom'].set_visible(False)
ax2.spines['left'].set_visible(False)

# Create a subplot for zooming in (top-left of the upper plot)
left, bottom, width, height = [0.69+shift_x, 0.66+shift_y, 0.28, 0.24]  # Adjust these values as needed
ax_zoom = fig.add_axes([left, bottom, width, height])
ax_zoom.set_ylim(0, 0.12)
ax_zoom.set_xlim(-0.4, 0.4)

ax_zoom.plot(data_gf_a1[:,0], -1/np.pi*data_gf_a1[:,2] , label=r'$\alpha=1.0$', color='r')
ax_zoom.plot(data_gf_a05[:,0], -1/np.pi*data_gf_a05[:,2] , label=r'$\alpha=0.5$', color='orange')
ax_zoom.plot(data_gf_a0[:,0], -1/np.pi*data_gf_a0[:,2] , label=r'$\alpha=0.0$', color='k')

# Show more tick dashes (optional)
# ax_zoom.set_xticks([1e-4, 1e-2, 1e0])
# ax_zoom.set_yticks([1e-2, 1e-1, 1e0])
ax_zoom.minorticks_off()

ax_zoom.tick_params(axis='x', which='both',bottom=True, top=False, labelsize=10)
ax_zoom.tick_params(axis='y', which='both',left=True, right=False, labelsize=9)

axs[1].plot(data_gc1_a1[:,0], -1/np.pi*data_gc1_a1[:,2] , label=r'$\alpha=1.0$', color='r')
axs[1].plot(data_gc1_a05[:,0], -1/np.pi*data_gc1_a05[:,2] , label=r'$\alpha=0.5$', color='orange')
axs[1].plot(data_gc1_a0[:,0], -1/np.pi*data_gc1_a0[:,2] , label=r'$\alpha=0.0$', color='k')
#axs[1].legend()
axs[1].set_ylim(0, 0.15)  # Set the y-range for the first subplot
axs[1].set_ylabel(r'$\rho^c_1(\omega)$')
axs[1].set_yticklabels(['0.0', '0.1'])

axs[2].plot(data_gc2_a0[:,0], -1/np.pi*data_gc2_a0[:,2] , label=r'$\alpha=0.0$', color='k')
axs[2].plot(data_gc2_a05[:,0], -1/np.pi*data_gc2_a05[:,2] , label=r'$\alpha=0.5$', color='orange')
axs[2].plot(data_gc2_a1[:,0], -1/np.pi*data_gc2_a1[:,2] , label=r'$\alpha=1.0$', color='r')
legend = axs[2].legend()
for handle in legend.legendHandles:
    handle.set_linewidth(2.2)
axs[2].set_ylim(0, 0.15)  # Set the y-range for the first subplot
axs[2].set_ylabel(r'$\rho^c_2(\omega)$')
axs[2].set_yticklabels(['0.0', '0.1'])
# axs[2].set_xticklabels(['0', '2', '4', '6', '8'])


# Remove tick numbers from the upper two subplots
axs[0].xaxis.set_tick_params(which='both', bottom=True, top=True, labelbottom=False)
axs[1].xaxis.set_tick_params(which='both', bottom=True, top=True, labelbottom=False)

axs[0].annotate('(a)', xy=(-7.5, 0.11), fontsize=18)
axs[1].annotate('(b)', xy=(-7.5, 0.11), fontsize=18)
axs[2].annotate('(c)', xy=(-7.5, 0.11), fontsize=18)


# Set labels and title
axs[2].set_xlabel(r'$\omega/\Gamma$')


plt.tight_layout() 
#Show the plot
#plt.show()
plt.savefig('fig2.png')