import matplotlib.pyplot as plt
import numpy as np 
from matplotlib.ticker import ScalarFormatter

style_path = '../paper.mplstyle'
plt.style.use(style_path)

# Load the data from the file using numpy
data_gf_a1_4 = np.loadtxt('data_PHAsym/Gf_a-1.0_Ef--4')
data_gf_a1_3 = np.loadtxt('data_PHAsym/Gf_a-1.0_Ef--3')
data_gf_a1_2 = np.loadtxt('data_PHAsym/Gf_a-1.0_Ef--2')
data_gf_a1_6 = np.loadtxt('data_PHAsym/Gf_a-1.0_Ef--6')
data_gf_a1_7 = np.loadtxt('data_PHAsym/Gf_a-1.0_Ef--7')


data_gc1_a1_4 = np.loadtxt('data_PHAsym/Gc1_a-1.0_Ef--4')
data_gc1_a1_3 = np.loadtxt('data_PHAsym/Gc1_a-1.0_Ef--3')
data_gc1_a1_2 = np.loadtxt('data_PHAsym/Gc1_a-1.0_Ef--2')
data_gc1_a1_6 = np.loadtxt('data_PHAsym/Gc1_a-1.0_Ef--6')
data_gc1_a1_7 = np.loadtxt('data_PHAsym/Gc1_a-1.0_Ef--7')



# Create a figure and three subplots stacked vertically with shared x-axis and no spacing
fig, axs = plt.subplots(1, 2, figsize=(6, 3.5), sharey=True)#, gridspec_kw={'wspace': 0.1})

axs[0].set_position([0.15, 0.1, 0.3, 0.77])
axs[1].set_position([0.6, 0.1, 0.3, 0.77])

# Plot data on the subplots
axs[0].plot(data_gf_a1_2[:,0], -1/np.pi*data_gf_a1_2[:,2] , label=r'$\alpha=1.0$', color='k')
axs[0].plot(data_gf_a1_3[:,0], -1/np.pi*data_gf_a1_3[:,2] , label=r'$\alpha=1.0$', color='orange')
axs[0].plot(data_gf_a1_4[:,0], -1/np.pi*data_gf_a1_4[:,2] , label=r'$\alpha=1.0$', color='b')
axs[0].plot(data_gf_a1_7[:,0], -1/np.pi*data_gf_a1_7[:,2], linestyle='--' , label=r'$\alpha=1.0$', color='orange')
#axs[0].legend()
axs[0].set_title(r'$\rho^f(\omega)$')
axs[0].set_ylim(-0.0005, 0.027)  # Set the y-range for the first subplot
axs[0].set_xlim(-0.005, 0.01)  # Set the y-range for the first subplot
ytick_positions = [0, 0.01, 0.02]  # Define the desired tick positions
ytick_labels = ['0.00', '0.01', '0.02']  # Define the corresponding labels
xtick_positions = [-0.005, 0, 0.005]  # Define the desired tick positions
xtick_labels = ['-0.005', '0', '0.005']  # Define the corresponding labels
axs[0].set_yticks(ytick_positions)
axs[0].set_yticklabels(ytick_labels)
axs[0].set_xticks(xtick_positions)
axs[0].set_xticklabels(xtick_labels)



axs[1].plot(data_gc1_a1_2[:,0], -1/np.pi*data_gc1_a1_2[:,2] , label=r'$\epsilon^f/\Gamma=-2$', color='k')
axs[1].plot(data_gc1_a1_3[:,0], -1/np.pi*data_gc1_a1_3[:,2] , label=r'$\epsilon^f/\Gamma=-3$', color='orange')
axs[1].plot(data_gc1_a1_4[:,0], -1/np.pi*data_gc1_a1_4[:,2] , label=r'$\epsilon^f/\Gamma=-4$', color='b')
axs[1].plot(data_gc1_a1_7[:,0], -1/np.pi*data_gc1_a1_7[:,2], linestyle='--' , label=r'$\epsilon^f/\Gamma=-7$', color='orange')
legend = axs[1].legend(loc=(-0.35, 0.32), framealpha=0.9)
for handle in legend.legendHandles:
    handle.set_linewidth(2.2)
axs[1].set_xlim(-0.005, 0.01)  # Set the y-range for the first subplot
axs[1].set_title(r'$\rho^c_1(\omega)$')
xtick_positions = [-0.005, 0, 0.005, 0.01]  # Define the desired tick positions
xtick_labels = ['-0.005', '0', '0.005', '0.01']  # Define the corresponding labels
axs[1].set_xticks(xtick_positions)
axs[1].set_xticklabels(xtick_labels)


# Remove tick numbers from the upper two subplots
axs[0].xaxis.set_tick_params(which='both', bottom=True, top=False, labelbottom=True)
axs[1].xaxis.set_tick_params(which='both', bottom=True, top=False, labelbottom=True)

axs[0].annotate('(a)', xy=(-0.0045, 0.002), fontsize=18)
axs[1].annotate('(b)', xy=(-0.0045, 0.002), fontsize=18)


# Set labels and title
axs[0].set_xlabel(r'$\omega/\Gamma$')
axs[1].set_xlabel(r'$\omega/\Gamma$')


plt.tight_layout() 
#Show the plot
#plt.show()
plt.savefig('fig5.png')