import matplotlib.pyplot as plt
import numpy as np 
import os


style_path = '../paper.mplstyle'
plt.style.use(style_path)

def plot_data(ax, data):
    factor = data[3310,2]
    ax.plot(data[:,0], data[:,2]/factor, lw=2)

# Get a list of all data files in the 'data' directory
data_directory = 'data'
data_files = [file for file in os.listdir(data_directory) if file.endswith('.dat')]

# Create an empty list to store the data arrays
Data = []

# Loop through the data files and append them to the Data list
for data_file in data_files:
    data_path = os.path.join(data_directory, data_file)
    data_array = np.loadtxt(data_path)
    Data.append(data_array)

# Get a list of all data files in the 'data' directory
data_directory = 'data_Gc'
data_files = [file for file in os.listdir(data_directory) if file.endswith('.dat')]

# Create an empty list to store the data arrays
Data_Gc = []

# Loop through the data files and append them to the Data list
for data_file in data_files:
    data_path = os.path.join(data_directory, data_file)
    data_array = np.loadtxt(data_path)
    Data_Gc.append(data_array)

# Create a figure and three subplots stacked vertically with shared x-axis and no spacing
fig, ax = plt.subplots(2, 1, figsize=(6, 4.5), sharex=True, gridspec_kw={'hspace': 0})

ax[0].set_ylim(1e-5, 5)
ax[0].set_xlim(9e-8, 10)
ax[0].set_xscale('log')
ax[0].set_yscale('log')

ax[1].set_ylim(0.8, 100)
ax[1].set_xlim(9e-8, 10)
ax[1].set_xscale('log')
ax[1].set_yscale('log')

for data in Data:
    plot_data(ax[1], data)

for data in Data_Gc:
    plot_data(ax[0], data)


e_1 = 1./3.
e_2 = -1./3.
x_func = np.linspace(1e-8, 10, 100)
y_func1 = 1/(1e-7**e_1)*x_func**e_1
y_func2 = 1/(1e-7**e_2)*x_func**e_2
ax[1].plot(x_func, y_func1,'--', color='k', lw=2)
ax[0].plot(x_func, y_func2,'--', color='k', lw=2)

ax[1].set_ylabel(r'$\rho^{\rm{f}}(\omega)$')
ax[0].set_ylabel(r'$\rho^{\rm{c}}_1(\omega)$')
ax[1].set_xlabel(r'$\omega/\Gamma$')

ytick_positions_0 = [1e-3, 1e0]
ytick_positions_1 = [1, 1e1]
ax[0].set_yticks(ytick_positions_0)
ax[1].set_yticks(ytick_positions_1)

ax[0].minorticks_off()
ax[1].minorticks_off()

ax[0].annotate('(a)', xy=(5e-7, 0.002), fontsize=19)
ax[1].annotate('(b)', xy=(5e-7, 10), fontsize=19)

plt.tight_layout() 
#Show the plot
#plt.show()
plt.savefig('fig3.png')